function H = computeLossyRadialH(sourcePowers, sourcePhases, R, Z0, k, time, freq)
%% computeLossyRadialH compute magnetic field from isotropic radiating source.
% Computation include free space losses.
%
%  INPUTS:
%   sourcePowers: powers of sources in watts, double [1 x 1 x N]
%   sourcePhases: phases of radiated field at zero time in radians, double [1 x 1 x N]
%   R: distances of points from sources in meters, double [K x L x N]
%   Z0: impedance of free space, double [1 x 1]
%   k: wave number, radians/m, double [1 x 1]
%   time: time in seconds when to compute field state, double [1 x 1]
%   freq: frequency of source signal, double [1 x 1]
%
%  OUTPUTS:
%   H: magnetic field in A/m in 2D cut, complex double [K x L]
%
% © 2020, Viktor Adler, CTU in Prague, adlervik@fel.cvut.cz

H0 = sqrt(sourcePowers./Z0/2/pi./R.^2);
H = sum(H0.*exp(1j*(-k*R + sourcePhases + 2*pi*freq*time)), 3);
end